#delimit ;
set more off;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      interaction1.do                                 *;
*       Date:           1/6/2013                                        *;
*       Author:         MG                                              *;
*       Purpose:        Do-file to produce a marginal effect plot for   *;
*                       X when the interaction model is:                *;
*                       Y = b0 + b1X + b2Z + b3XZ + e                   *;
*       Input File:     alexseev.dta 	                                *;
*       Output File:    interaction1.log                                *;
*       Data Output:    None	                                        *;
*       Previous file:  None                                            *;
*       Machine:        laptop                                          *;
*     ****************************************************************  *;
*     ****************************************************************  *;

use "/Users/sambell/Dropbox/NGOs and Trafficking/Data/Final.9.26.2016.dta", clear;

*     ****************************************************************  *;
*     ****************************************************************  *;
*	  Get stuff ready to produce a marginal effect for X.               *;
*     ****************************************************************  *;
*     ****************************************************************  *;

set obs 15000;

eststo: xtreg f_Overall3P whrnoposmgoldtotal wingos  wingos_shaming cedaw_rat_1  log_gdp log_pop polity2 overallglobalizationindex, re;

matrix b=e(b);
matrix V=e(V);

scalar b1=b[1,1];
scalar b3=b[1,3];

scalar varb1=V[1,1];
scalar varb3=V[3,3];

scalar covb1b3=V[1,3];

scalar list b1 b3 varb1 varb3 covb1b3;

*     ****************************************************************  *;
*       Calculate data necessary for top marginal effect plot.          *;
*     ****************************************************************  *;

generate MVZ=((_n));

replace  MVZ=. if _n>107;

gen conbx=b1+b3*MVZ if _n<107;

gen consx=sqrt(varb1+varb3*(MVZ^2)+2*covb1b3*MVZ) if _n<107;

gen ax=1.96*consx;

gen upperx=conbx+ax;

gen lowerx=conbx-ax;

*     ****************************************************************  *;
*       Construct stuff to produce the rug plot.  Need to create an     *;
*       offset position for the pipe marker, which will depend on       *;
*       where the histogram sits on the y-axis. This will requie some   *;
*       trial and error.                                                *;
*     ****************************************************************  *;


*     ****************************************************************  *;
*       Construct variable to produce y=0 line.                         *;
*     ****************************************************************  *;

*note stop running .do file here and then run code for figure*

twoway (line conbx MVZ, lcolor(black) lpattern(solid)  mcolor(black)) (line lowerx MVZ, lcolor(black) lpattern(dash)  mcolor(black)) (line upperx MVZ, lcolor(black) lpattern(dash)  mcolor(black)), ytitle(Marginal Effect of Shaming) ytitle(, size(medium)) yline(0, lpattern(solid) lcolor(black) extend) ylabel(.05 (.025)-.05) xtitle(WRO Presence) xtitle(, size(medium)) xlabel(0(10)120) legend(off) scheme(s2mono) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
