#delimit ;
set more off;

*     ***************************************************************** *;
*     ***************************************************************** *;
*       File-Name:      interaction3.do                                 *;
*       Date:           1/8/2013                                        *;
*       Author:         MG                                              *;
*       Purpose:        Do-file to produce a marginal effect plot for   *;
*                       X when the interaction model is:                *;
*                       Pr(Y=1) = Phi(b0 + b1X + b2Z + b3XZ)            *;
*       Input File:     interaction3.dta                                *;
*       Output File:    interaction3.log                                *;
*       Data Output:    None	                                        *;
*       Previous file:  None                                            *;
*       Machine:        laptop                                          *;
*     ****************************************************************  *;
*     ****************************************************************  *;

use "/Users/sambell/Dropbox/NGOs and Trafficking/Data/Final.9.26.2016.dta", clear;

*     ****************************************************************  *;
*                           Estimate Probit Model                       *;
*     ****************************************************************  *;           
             
eststo: xtprobit f_source whrnoposmgoldtotal wingos wingos_shaming cedaw_rat_1  log_gdp log_pop  polity2 overallglobalizationindex, re;
        
*     ****************************************************************  *;
*       Take 10,000 draws from the estimated coefficient vector and     *;
*       variance-covariance matrix.                                     *;
*     ****************************************************************  *;

preserve;

set seed 339487731;

drawnorm SN_b1-SN_b10, n(50000) means(e(b)) cov(e(V)) clear;

*     ****************************************************************  *;
*       To calculate the desired quantities of interest we need to set  *;
*       up a loop.  This is what we do here.                            *;
*     ****************************************************************  *;
*       First, specify what you quantities should be saved and what     *;
*       these quantities should be called.                              *;
*     ****************************************************************  *;

postutil clear;
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi 
            using "/Users/sambell/Dropbox/NGOs and Trafficking/Data/sim.dta", replace;
            
noisily display "start";
            
*     ****************************************************************  *;
*       Start loop.  Let `a' be the modifying variable Z and let this   *;
*       run from min to max in the desired increments.                  *;
*     ****************************************************************  *; 

local a=1 ;
while `a' <= 192 { ;

{;

scalar h_whrnoposmgoldtotal=6.06;
scalar h_cedaw_rat_1=1;
scalar h_log_gdp=7.97;
scalar h_log_pop=16.42;
scalar h_polity2= 3.9;
scalar h_overallglobalizationindex=.21;
scalar h_constant=1;          

    generate x_betahat0  = SN_b1*h_whrnoposmgoldtotal 
                            + SN_b2*`a'   
                            + SN_b3*h_whrnoposmgoldtotal*`a' 
                            + SN_b4*h_cedaw_rat_1 
                            + SN_b5*h_log_gdp
                            + SN_b6*h_log_pop
                            + SN_b7*h_polity2
                            + SN_b8*h_overallglobalizationindex
                            + SN_b9*h_constant;
                            
    generate x_betahat1  = SN_b1*(h_whrnoposmgoldtotal+17.45) 
                            + SN_b2*`a'   
                            + SN_b3*(h_whrnoposmgoldtotal+17.45)*`a' 
                            + SN_b4*h_cedaw_rat_1 
                            + SN_b5*h_log_gdp
                            + SN_b6*h_log_pop
                            + SN_b7*h_polity2
                            + SN_b8*h_overallglobalizationindex
                            + SN_b9*h_constant;
    
    gen prob0 =normal(x_betahat0);
    gen prob1=normal(x_betahat1);
    gen diff=prob1-prob0;
    
    egen probhat0 =mean(prob0);
    egen probhat1=mean(prob1);
    egen diffhat=mean(diff);
    
    tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi;  

    _pctile prob0, p(2.5,97.5) ;
    scalar `lo0' = r(r1);
    scalar `hi0' = r(r2);  
    
    _pctile prob1, p(2.5,97.5);
    scalar `lo1'= r(r1);
    scalar `hi1'= r(r2);  
    
    _pctile diff, p(2.5,97.5);
    scalar `diff_lo'= r(r1);
    scalar `diff_hi'= r(r2);  
   
    scalar `prob_hat0'=probhat0;
    scalar `prob_hat1'=probhat1;
    scalar `diff_hat'=diffhat;
    
    post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') 
                (`diff_hat') (`diff_lo') (`diff_hi');
   
    };      
    
    drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat;
    
    local a=`a'+ 1;
    
    display "." _c;
    
} ;

display "";

postclose mypost;

*     ****************************************************************  *;                                  
*       Call on posted quantities of interest                           *;
*     ****************************************************************  *;

*note stop running .do file here and then run code for figure*


use "/Users/sambell/Dropbox/NGOs and Trafficking/Data/sim.dta"

gen MV = _n

replace  MV=. if _n>121

twoway (line diff_hat MV, lcolor(black) lpattern(solid)  mcolor(black)) (line diff_lo MV, lcolor(black) lpattern(dash)  mcolor(black)) (line diff_hi MV, lcolor(black) lpattern(dash)  mcolor(black)), ytitle(Marginal Effect of Shaming) ytitle(, size(medium)) yline(0, lpattern(solid) lcolor(black) extend) ylabel(.2 (.2)-.7) xtitle(WRO Presence) xtitle(, size(medium)) xlabel(0(10)121) legend(off) scheme(s2mono) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))


